======
Thonny
======

Thonny is a Python IDE meant for learning programming.

End users
---------
See http://thonny.org for more info.


Contributors
------------
Contributions are welcome! See `CONTRIBUTING.rst <https://bitbucket.org/plas/thonny/src/master/CONTRIBUTING.rst>`_ for more info.